ImageLayerData class

Attributes used by ImageLayer

Inheritance

Constructors

ImageLayerData({Key? key, required ImageItem image, double size = 64, Offset? offset, double? opacity, double? rotation, double? scale})

Properties

hashCode → int
The hash code for this object.
no setterinherited
image ↔ ImageItem
getter/setter pair
offset ↔ Offset
getter/setter pairinherited
opacity ↔ double
getter/setter pairinherited
rotation ↔ double
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
getter/setter pairinherited
size ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited